@@ -1,6 +1,10 @@
-__version__ = "0.6.14"
-
 import logging
+from importlib.metadata import PackageNotFoundError, version
+
+try:
+    __version__ = version("aind-clabe")
+except PackageNotFoundError:
+    __version__ = "0.0.0"
 
 from . import logging_helper
 
